CREATE TABLE IF NOT EXISTS `inlineeditor_text` ( 
`id_inlineeditor_text` int(11) NOT NULL AUTO_INCREMENT,
`i_id` varchar(255) CHARACTER SET utf8 NOT NULL,
`value` mediumtext,
`id_resource_type_page` int(11),
`id_lan` int(11),
PRIMARY KEY (`id_inlineeditor_text`) 
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;
